<?php
# Copyright © VeriTrans Inc. All rights reserved.

// -------------------------------------------------------------------------
// Amazon Payの決済確認画面のサンプル
// -------------------------------------------------------------------------

define('MDK_DIR', '../tgMdk/');

define('TXN_FAILURE_CODE', 'failure');
define('TXN_PENDING_CODE', 'pending');
define('TXN_SUCCESS_CODE', 'success');
define('TRUE_FLAG_CODE', 'true');
define('FALSE_FLAG_CODE', 'false');

define('ERROR_PAGE_TITLE', 'System Error');
define('NORMAL_PAGE_TITLE', '決済確認画面');

require_once(MDK_DIR."3GPSMDK.php");

/**
 * 取引ID
 */
$order_id = htmlspecialchars(@$_GET["orderId"]);

/**
 * ハッシュ値
 */
$order_hash = htmlspecialchars(@$_GET["orderHash"]);

// 改ざんチェック
$conf = TGMDK_Config::getInstance();
$array = $conf->getConnectionParameters();
$merchant_cc_id = $array[TGMDK_Config::MERCHANT_CC_ID];
$merchant_pw = $array[TGMDK_Config::MERCHANT_SECRET_KEY];

$hash_key = $merchant_cc_id . $order_id . $merchant_pw;
$hash_value = sha1($hash_key);

//ダミー取引確認
$is_dummy = $array[TGMDK_Config::DUMMY_REQUEST];

if (!isset($hash_value) || $hash_value != $order_hash) {
  $warn_msg = "<font color='#ff0000'><b>【パラメータ改竄】パラメータ情報が改竄されています。</b></font><br/><br/>";
} else {
  echo "<!-- orderHash check is OK -->";

  /**
   * 要求電文パラメータ値の指定
   */
  $request_data = new AmazonpayGetAddressRequestDto();

  $request_data->setOrderId($order_id);
  $request_data->setAddInfoRespFlag('1');

  /**
   * 実施
   */
  $transaction = new TGMDK_Transaction();
  $response_data = $transaction->execute($request_data);

  //予期しない例外
  if (!isset($response_data)) {
    $page_title = ERROR_PAGE_TITLE;
  //想定応答の取得
  } else {
    $page_title = NORMAL_PAGE_TITLE;
    $txn_status = $response_data->getMStatus();

    if (TXN_SUCCESS_CODE === $txn_status) {
      // 取得した住所から送料・決済金額を計算して更新して決済確認画面に反映する
      session_start();
      $original_amount = $_SESSION['original_amount'];
      $shipping_amount = '0';
      $amount = $original_amount + $shipping_amount;

      // サーバー側で保持する情報
      $_SESSION['amount'] = $amount;
      $_SESSION['pay_redirectUrl'] = $response_data->getPayRedirectUrl();

      if ($is_dummy) {
        $checkout_result_return_url = $_SESSION['pay_confirm_screen_url'] . "?orderId=" . $order_id . "&orderHash=" . $order_hash;
      } else {
        $checkout_session_id = $response_data->getCheckoutSessionId();
      }
    } 
  }
}
?>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta http-equiv="Content-Language" content="ja" />
<title>決済情報確認ページ</title>
<link href="../css/style.css" rel="stylesheet" type="text/css">
</head>
<body>
<img alt="Paymentロゴ" src="../WEB-IMG/VeriTrans_Payment.png"><hr/>
<div class="system-message">
<font size="2">
本画面はVeriTrans4G Amazon Payの取引サンプル画面です。<br/>
お客様ECサイトのショッピングカートとVeriTrans4Gとを連動させるための参考、例としてご利用ください。<br/>
</font>
</div>

<div class="lhtitle">Amazon Pay与信：決済確認画面 <?php if ($is_dummy) { echo "(ダミー取引用)"; } ?></div>


<?php
  if (!empty($warn_msg)) {
    echo $warn_msg . "<br>";
  } else if (TXN_SUCCESS_CODE === $txn_status) {
?>


<?php if ($is_dummy) { ?>
  <form name="ChangeForm" action="https://api3.veritrans.co.jp/dummy-amazonpay/SelectAddressAndPaymentMethod" method="post" id="ChangeForm">
  <input type="hidden" name="checkoutResultReturnUrl" value="<?php echo $checkout_result_return_url ?>">
<?php } ?>


<table border="0" cellpadding="0" cellspacing="0">
  <tr>
    <td class="rititletop">名前（配送先）</td>
    <td class="rivaluetop"><?php echo $response_data->getShippingName() ?><br />
    </td>
  </tr>
  <tr>
    <td class="rititle">郵便番号</td>
    <td class="rivalue"><?php echo $response_data->getShippingPostalCode() ?><br />
    </td>
  </tr>
  <tr>
    <td class="rititle">配送先住所1</td>
    <td class="rivalue"><?php echo $response_data->getShippingAddress1() ?><br />
    </td>
  </tr>
  <tr>
    <td class="rititle">配送先住所2</td>
    <td class="rivalue"><?php echo $response_data->getShippingAddress2() ?><br />
    </td>
  </tr>
  <tr>
    <td class="rititle">配送先住所3</td>
    <td class="rivalue"><?php echo $response_data->getShippingAddress3() ?><br />
    </td>
  </tr>
  <tr>
    <td class="rititle">電話番号</td>
    <td class="rivalue"><?php echo $response_data->getShippingPhone() ?><br />
    </td>
  </tr>
</table>


<?php if ($is_dummy) { ?>
  <div>
    <button type="submit" class="change_btn">お届け先修正</button>
  </div>
<?php } else { ?>
  <div>
    <button type="button" class="change_btn" id="AddressChange">お届け先修正</button>
  </div>
<?php } ?>


<br />
<table border="0" cellpadding="0" cellspacing="0">
  <tr>
    <td class="rititletop">AmazonID</td>
    <td class="rivaluetop"><?php echo $response_data->getBuyerId() ?><br />
    </td>
  </tr>
  <tr>
    <td class="rititle">名前（購入者）</td>
    <td class="rivalue"><?php echo $response_data->getBuyerName() ?><br />
    </td>
  </tr>
  <tr>
    <td class="rititle">請求先住所1</td>
    <td class="rivalue"><?php echo $response_data->getBillingAddress1() ?><br />
    </td>
  </tr>
  <tr>
    <td class="rititle">請求先住所2</td>
    <td class="rivalue"><?php echo $response_data->getBillingAddress2() ?><br />
    </td>
  </tr>
  <tr>
    <td class="rititle">請求先住所3</td>
    <td class="rivalue"><?php echo $response_data->getBillingAddress3() ?><br />
    </td>
  </tr>
  <tr>
    <td class="rititle">メールアドレス</td>
    <td class="rivalue"><?php echo $response_data->getBuyerEmail() ?><br />
    </td>
  </tr>
  <tr>
    <td class="rititle">お支払い方法</td>
    <td class="rivalue"><?php echo $response_data->getPaymentPreferences() ?><br />
    </td>
  </tr>
  <tr>
    <td class="rititle">取引金額</td>
    <td class="rivalue"><?php echo $amount ?><br />
    </td>
  </tr>
  <tr>
    <td class="rititle">送料</td>
    <td class="rivalue"><?php echo $shipping_amount ?><br />
    </td>
  </tr>
</table>


<?php if ($is_dummy) { ?>
  <div>
    <button type="submit" class="change_btn">支払い方法修正</button>
  </div>
<?php } else { ?>
  <div>
  <button type="button" class="change_btn" id="PaymentChange">支払い方法修正</button>
  </div>
<?php } ?>


</form>
<br />
<form name="FORM_AmazonPay" method="post" action="AuthorizeConfirmExec.php">
  <br />
  <input type="submit" value="購入する">
</form>
<br />
<a href="../PaymentMethodSelect.php">キャンセル</a>
&nbsp;&nbsp;


<?php if (!$is_dummy) { ?>
  <script type="text/javascript" src="https://static-na.payments-amazon.com/checkout.js"></script>
  <script type="text/javascript">
    amazon.Pay.bindChangeAction('#AddressChange', {
      amazonCheckoutSessionId: '<?php echo $checkout_session_id ?>',
      changeAction: 'changeAddress'
    });

    amazon.Pay.bindChangeAction('#PaymentChange', {
      amazonCheckoutSessionId: '<?php echo $checkout_session_id ?>',
      changeAction: 'changePayment'
    });
  </script>
<?php } ?>


<?php } else { ?>


<table border="0" cellpadding="0" cellspacing="0">
  <tr>
    <td class="rititletop">取引ID</td>
    <td class="rivaluetop"><?php echo $response_data->getOrderId() ?><br/></td>
  </tr>
  <tr>
    <td class="rititle">取引ステータス</td>
    <td class="rivalue"><?php echo $response_data->getMStatus() ?><br/></td>
  </tr>
  <tr>
    <td class="rititle">結果コード</td>
    <td class="rivalue"><?php echo $response_data->getVResultCode() ?><br/></td>
  </tr>
  <tr>
    <td class="rititle">結果メッセージ</td>
    <td class="rivalue"><?php echo $response_data->getMerrMsg() ?><br/></td>
  </tr>
</table>

<br />
<a href="../PaymentMethodSelect.php">決済サンプルのトップメニューへ戻る</a>&nbsp;&nbsp;


<?php } ?>


<hr />
<img alt="VeriTransロゴ" src="../WEB-IMG/VeriTransLogo_WH.png">&nbsp; Copyright &copy; VeriTrans Inc. All rights reserved
  
</body></html>
