<?php
# Copyright © VeriTrans Inc. All rights reserved.

// -------------------------------------------------------------------------
// Amazon Payの実行および結果画面のサンプル
// -------------------------------------------------------------------------

define('MDK_DIR', '../tgMdk/');

define('INPUT_PAGE', 'Authorize.php');

define('TXN_FAILURE_CODE', 'failure');
define('TXN_PENDING_CODE', 'pending');
define('TXN_SUCCESS_CODE', 'success');
define('TRUE_FLAG_CODE', 'true');
define('FALSE_FLAG_CODE', 'false');

define('ERROR_PAGE_TITLE', 'System Error');
define('NORMAL_PAGE_TITLE', '取引結果');

require_once(MDK_DIR."3GPSMDK.php");

/**
 * 取引ID
 */
$order_id = @$_POST["orderId"];

/**
 * 決済金額
 */
$amount = @$_POST["amount"];

/**
 * 売上フラグ
 */
$is_with_capture = @$_POST["withCapture"];
if ("1" == $is_with_capture) {
  $is_with_capture = TRUE_FLAG_CODE;
} else {
  $is_with_capture = FALSE_FLAG_CODE;
}

/**
 * 配送先表示抑止フラグ
 */
$is_suppress_shipping_address_view = @$_POST["suppressShippingAddressView"];
if ("1" == $is_suppress_shipping_address_view) {
  $is_suppress_shipping_address_view = TRUE_FLAG_CODE;
} else {
  $is_suppress_shipping_address_view = FALSE_FLAG_CODE;
}

/**
 * 注文説明
 */
$note_to_buyer = @$_POST["noteToBuyer"];

/**
 * 完了時URL
 */
$success_url = @$_POST["successUrl"];

/**
 * キャンセル時URL
 */
$cancel_url = @$_POST["cancelUrl"];

/**
 * エラー時URL
 */
$error_url = @$_POST["errorUrl"];

/**
 * 決済確認画面種別
 */
$pay_confirm_screen_type = @$_POST["payConfirmScreenType"];

/**
 * 決済確認画面URL
 */
$pay_confirm_screen_url = @$_POST["payConfirmScreenUrl"];


/**
 * 必須パラメータ値チェック
 */
//サーバ内部指定
if (empty($order_id)){
  $warning =  "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
  include_once(INPUT_PAGE);
  exit;
//サーバ内部指定
} else if (empty($amount)) {
  $warning =  "<font color='#ff0000'><b>必須項目：決済金額が指定されていません</b></font>";
  include_once(INPUT_PAGE);
  exit;
}

/**
 * 要求電文パラメータ値の指定
 */
$request_data = new AmazonpayAuthorizeRequestDto();

$request_data->setOrderId($order_id);
$request_data->setAmount($amount);
$request_data->setWithCapture($is_with_capture);
$request_data->setSuppressShippingAddressView($is_suppress_shipping_address_view);
$request_data->setNoteToBuyer($note_to_buyer);
$request_data->setSuccessUrl($success_url);
$request_data->setCancelUrl($cancel_url);
$request_data->setErrorUrl($error_url);
$request_data->setPayConfirmScreenType($pay_confirm_screen_type);
$request_data->setPayConfirmScreenUrl($pay_confirm_screen_url);

/**
 * 実施
 */
$transaction = new TGMDK_Transaction();
$response_data = $transaction->execute($request_data);

//予期しない例外
if (!isset($response_data)) {
  $page_title = ERROR_PAGE_TITLE;
//想定応答の取得
} else {
  $page_title = NORMAL_PAGE_TITLE;

  /**
   * 取引ID取得
   */
  $result_order_id = $response_data->getOrderId();
  /**
   * 結果コード取得
   */
  $txn_status = $response_data->getMStatus();
  /**
   * 詳細コード取得
   */
  $txn_result_code = $response_data->getVResultCode();
  /**
   * エラーメッセージ取得
   */
  $error_message = $response_data->getMerrMsg();

  // ログ
  $test_log = "<!-- vResultCode=" . $txn_result_code . " -->";

  if (TXN_SUCCESS_CODE === $txn_status) {
      // 成功
      // セッションに情報を保存
      session_start();
      $_SESSION['order_id'] = $order_id;
      $_SESSION['original_amount'] = $amount;
      $_SESSION['pay_confirm_screen_url'] = $pay_confirm_screen_url;

      $response_html = $response_data->getResponseContents();
      header("Content-type: text/html; charset=UTF-8");
      echo $response_html . $test_log;
      exit;
  } else {
      // エラーページ表示
      $title = "エラーページ";
      $html = createResultPage($response_data, $title);
      print $html . $test_log;
      exit;
  }
}

function createResultPage($response, $title) {

$html = '<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta http-equiv="Content-Language" content="ja" />
<title>'.$title.'</title>
<link href="../css/style.css" rel="stylesheet" type="text/css">
</head>
<body>
<img alt="Paymentロゴ" src="../WEB-IMG/VeriTrans_Payment.png"><hr/>
<div class="system-message">
<font size="2">
本画面はVeriTrans4G Amazon Payの取引サンプル画面です。<br/>
お客様ECサイトのショッピングカートとVeriTrans4Gとを連動させるための参考、例としてご利用ください。<br/>
</font>
</div>

<div class="lhtitle">Amazon Pay：取引結果</div>
<table border="0" cellpadding="0" cellspacing="0">
  <tr>
    <td class="rititletop">取引ID</td>
    <td class="rivaluetop">'.$response->getOrderId().'<br/></td>
  </tr>
  <tr>
    <td class="rititle">取引ステータス</td>
    <td class="rivalue">'.$response->getMStatus().'</td>
  </tr>
  <tr>
    <td class="rititle">結果コード</td>
    <td class="rivalue">'.$response->getVResultCode().'</td>
  </tr>
  <tr>
    <td class="rititle">結果メッセージ</td>
    <td class="rivalue">'.$response->getMerrMsg().'</td>
  </tr>
</table>
<br/>

<a href="../PaymentMethodSelect.php">決済サンプルのトップメニューへ戻る</a>&nbsp;&nbsp;

<hr>
<img alt="VeriTransロゴ" src="../WEB-IMG/VeriTransLogo_WH.png">&nbsp; Copyright &copy; VeriTrans Inc. All rights reserved


</body></html>';

 return $html;
}
?>
