<?php
# Copyright © VeriTrans Inc. All rights reserved.

// -------------------------------------------------------------------------
// Amazon Pay 住所情報取得の実行および結果画面のサンプル
// -------------------------------------------------------------------------

define('MDK_DIR', '../tgMdk/');

define('INPUT_PAGE', 'GetAddress.php');

define('TXN_FAILURE_CODE', 'failure');
define('TXN_PENDING_CODE', 'pending');
define('TXN_SUCCESS_CODE', 'success');
define('TRUE_FLAG_CODE', 'true');
define('FALSE_FLAG_CODE', 'false');

define('ERROR_PAGE_TITLE', 'System Error');
define('NORMAL_PAGE_TITLE', '取引結果');

require_once(MDK_DIR."3GPSMDK.php");

// 変数の初期化
$orderId = "";
$txn_status = "";
$txn_result_code = "";
$error_message = "";

/**
 * 取引ID
 */
$order_id = @$_POST["orderId"];

/**
 * 必須パラメータ値チェック
 */
 if (empty($order_id)){
  $warning =  "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
  include_once(INPUT_PAGE);
  exit;
 }
/**
 * 要求電文パラメータ値の指定
 */
 $request_data = new AmazonpayGetAddressRequestDto();

 $request_data->setOrderId($order_id);

/**
 * 実施
 */
 $transaction = new TGMDK_Transaction();
 $response_data = $transaction->execute($request_data);

 //予期しない例外
 if (!isset($response_data)) {
  $page_title = ERROR_PAGE_TITLE;
 //想定応答の取得
 } else {
  // 取引ID
  $orderId = $response_data->getOrderId();

  $page_title = NORMAL_PAGE_TITLE;

  /**
   * 結果コード取得
   */
  $txn_status = $response_data->getMStatus();
  /**
   * 詳細コード取得
   */
  $txn_result_code = $response_data->getVResultCode();
  /**
   * エラーメッセージ取得
   */
  $error_message = $response_data->getMerrMsg();
  /**
   * 決済センター応答日時取得
   */
  $center_response_datetime = $response_data->getCenterResponseDatetime();
  /**
   * 配送先：氏名取得
   */
  $shipping_name = $response_data->getShippingName();
  /**
   * 配送先：電話番号取得
   */
  $shipping_phone = $response_data->getShippingPhone();
  /**
   * 配送先：住所１取得
   */
  $shipping_address1 = $response_data->getShippingAddress1();
  /**
   * 配送先：住所２取得
   */
  $shipping_address2 = $response_data->getShippingAddress2();
  /**
   * 配送先：住所３取得
   */
  $shipping_address3 = $response_data->getShippingAddress3();
  /**
   * 配送先：都道府県取得
   */
  $shipping_prefecture = $response_data->getShippingPrefecture();
  /**
   * 配送先：郵便番号取得
   */
  $shipping_postal_code = $response_data->getShippingPostalCode();

  // 成功
  if (TXN_SUCCESS_CODE === $txn_status) {
  } else if (TXN_PENDING_CODE === $txn_status) {
  // 失敗
  } else if (TXN_FAILURE_CODE === $txn_status) {
  } else {
    $page_title = ERROR_PAGE_TITLE;
  }
 }
?>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta http-equiv="Content-Language" content="ja" />
<title><?php echo $page_title ?></title>
<link href="../css/style.css" rel="stylesheet" type="text/css">
</head>
<body>
<img alt='Paymentロゴ' src='../WEB-IMG/VeriTrans_Payment.png'><hr/>
<div class="system-message">
<font size="2">
本画面はVeriTrans4G Amazon Payの住所情報取得取引サンプル画面です。<br/>
お客様ECサイトのショッピングカートとVeriTrans4Gとを連動させるための参考、例としてご利用ください。<br/>
</font>
</div>
<div class="lhtitle">Amazon Pay住所情報取得：取引結果</div>
<table border="0" cellpadding="0" cellspacing="0">
  <tr>
    <td class="rititletop">取引ID</td>
    <td class="rivaluetop"><?php echo $orderId ?><br/></td>
  </tr>
  <tr>
    <td class="rititle">取引ステータス</td>
    <td class="rivalue"><?php echo $txn_status ?><br/></td>
  </tr>
  <tr>
    <td class="rititle">結果コード</td>
    <td class="rivalue"><?php echo $txn_result_code ?><br/></td>
  </tr>
  <tr>
    <td class="rititle">結果メッセージ</td>
    <td class="rivalue"><?php echo $error_message ?><br/></td>
  </tr>
  <tr>
    <td class="rititle">決済センター応答日時</td>
    <td class="rivalue"><?php echo $center_response_datetime ?><br/></td>
  </tr>
  <tr>
    <td class="rititle">配送先：氏名</td>
    <td class="rivalue"><?php echo $shipping_name ?><br/></td>
    </td>
  </tr>
  <tr>
    <td class="rititle">配送先：電話番号</td>
    <td class="rivalue"><?php echo $shipping_phone ?><br/></td>
    </td>
  </tr>
  <tr>
    <td class="rititle">配送先：住所１</td>
    <td class="rivalue"><?php echo $shipping_address1 ?><br/></td>
    </td>
  </tr>
  <tr>
    <td class="rititle">配送先：住所２</td>
    <td class="rivalue"><?php echo $shipping_address2 ?><br/></td>
    </td>
  </tr>
  <tr>
    <td class="rititle">配送先：住所３</td>
    <td class="rivalue"><?php echo $shipping_address3 ?><br/></td>
    </td>
  </tr>
  <tr>
    <td class="rititle">配送先：都道府県</td>
    <td class="rivalue"><?php echo $shipping_prefecture ?><br/></td>
    </td>
  </tr>
  <tr>
    <td class="rititle">配送先：郵便番号</td>
    <td class="rivalue"><?php echo $shipping_postal_code ?><br/></td>
    </td>
  </tr>
</table>

<br/>

<a href="../AdminMenu.php">管理メニューへ戻る</a>&nbsp;&nbsp;

<hr>
<img alt='VeriTransロゴ' src='../WEB-IMG/VeriTransLogo_WH.png'>&nbsp; Copyright &copy; VeriTrans Inc. All rights reserved

</body>
</html>
